@@ -56,7 +56,9 @@ __all__ = (
     "TargetDestinationType",
     "TransformationToolNameType",
     "VersionControlType",
+    "MigrationHubStrategyRecommendationsServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
 )
 
@@ -181,6 +183,7 @@ TransformationToolNameType = Literal[
     "Windows Web Application Migration Assistant",
 ]
 VersionControlType = Literal["GITHUB", "GITHUB_ENTERPRISE"]
+MigrationHubStrategyRecommendationsServiceName = Literal["migrationhubstrategy"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -212,6 +215,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -334,6 +338,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -482,6 +487,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "get_server_details",
     "list_application_components",
