@@ -15,6 +15,8 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence
 
+from typing_extensions import NotRequired
+
 from .literals import (
     AntipatternReportStatusType,
     ApplicationComponentCriteriaType,
@@ -136,88 +138,81 @@ __all__ = (
 AntipatternSeveritySummaryTypeDef = TypedDict(
     "AntipatternSeveritySummaryTypeDef",
     {
-        "count": int,
-        "severity": SeverityType,
+        "count": NotRequired[int],
+        "severity": NotRequired[SeverityType],
     },
-    total=False,
 )
 
 ApplicationComponentDetailTypeDef = TypedDict(
     "ApplicationComponentDetailTypeDef",
     {
-        "analysisStatus": SrcCodeOrDbAnalysisStatusType,
-        "antipatternReportS3Object": "S3ObjectTypeDef",
-        "antipatternReportStatus": AntipatternReportStatusType,
-        "antipatternReportStatusMessage": str,
-        "appType": AppTypeType,
-        "associatedServerId": str,
-        "databaseConfigDetail": "DatabaseConfigDetailTypeDef",
-        "id": str,
-        "inclusionStatus": InclusionStatusType,
-        "lastAnalyzedTimestamp": datetime,
-        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
-        "moreServerAssociationExists": bool,
-        "name": str,
-        "osDriver": str,
-        "osVersion": str,
-        "recommendationSet": "RecommendationSetTypeDef",
-        "resourceSubType": ResourceSubTypeType,
-        "sourceCodeRepositories": List["SourceCodeRepositoryTypeDef"],
-        "statusMessage": str,
+        "analysisStatus": NotRequired[SrcCodeOrDbAnalysisStatusType],
+        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
+        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
+        "antipatternReportStatusMessage": NotRequired[str],
+        "appType": NotRequired[AppTypeType],
+        "associatedServerId": NotRequired[str],
+        "databaseConfigDetail": NotRequired["DatabaseConfigDetailTypeDef"],
+        "id": NotRequired[str],
+        "inclusionStatus": NotRequired[InclusionStatusType],
+        "lastAnalyzedTimestamp": NotRequired[datetime],
+        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
+        "moreServerAssociationExists": NotRequired[bool],
+        "name": NotRequired[str],
+        "osDriver": NotRequired[str],
+        "osVersion": NotRequired[str],
+        "recommendationSet": NotRequired["RecommendationSetTypeDef"],
+        "resourceSubType": NotRequired[ResourceSubTypeType],
+        "sourceCodeRepositories": NotRequired[List["SourceCodeRepositoryTypeDef"]],
+        "statusMessage": NotRequired[str],
     },
-    total=False,
 )
 
 ApplicationComponentStrategyTypeDef = TypedDict(
     "ApplicationComponentStrategyTypeDef",
     {
-        "isPreferred": bool,
-        "recommendation": "RecommendationSetTypeDef",
-        "status": StrategyRecommendationType,
+        "isPreferred": NotRequired[bool],
+        "recommendation": NotRequired["RecommendationSetTypeDef"],
+        "status": NotRequired[StrategyRecommendationType],
     },
-    total=False,
 )
 
 ApplicationComponentSummaryTypeDef = TypedDict(
     "ApplicationComponentSummaryTypeDef",
     {
-        "appType": AppTypeType,
-        "count": int,
+        "appType": NotRequired[AppTypeType],
+        "count": NotRequired[int],
     },
-    total=False,
 )
 
 ApplicationPreferencesTypeDef = TypedDict(
     "ApplicationPreferencesTypeDef",
     {
-        "managementPreference": "ManagementPreferenceTypeDef",
+        "managementPreference": NotRequired["ManagementPreferenceTypeDef"],
     },
-    total=False,
 )
 
 AssessmentSummaryTypeDef = TypedDict(
     "AssessmentSummaryTypeDef",
     {
-        "antipatternReportS3Object": "S3ObjectTypeDef",
-        "antipatternReportStatus": AntipatternReportStatusType,
-        "antipatternReportStatusMessage": str,
-        "lastAnalyzedTimestamp": datetime,
-        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
-        "listApplicationComponentStrategySummary": List["StrategySummaryTypeDef"],
-        "listApplicationComponentSummary": List["ApplicationComponentSummaryTypeDef"],
-        "listServerStrategySummary": List["StrategySummaryTypeDef"],
-        "listServerSummary": List["ServerSummaryTypeDef"],
+        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
+        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
+        "antipatternReportStatusMessage": NotRequired[str],
+        "lastAnalyzedTimestamp": NotRequired[datetime],
+        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
+        "listApplicationComponentStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
+        "listApplicationComponentSummary": NotRequired[List["ApplicationComponentSummaryTypeDef"]],
+        "listServerStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
+        "listServerSummary": NotRequired[List["ServerSummaryTypeDef"]],
     },
-    total=False,
 )
 
 AssociatedApplicationTypeDef = TypedDict(
     "AssociatedApplicationTypeDef",
     {
-        "id": str,
-        "name": str,
+        "id": NotRequired[str],
+        "name": NotRequired[str],
     },
-    total=False,
 )
 
 AwsManagedResourcesTypeDef = TypedDict(
@@ -230,67 +225,61 @@ AwsManagedResourcesTypeDef = TypedDict(
 BusinessGoalsTypeDef = TypedDict(
     "BusinessGoalsTypeDef",
     {
-        "licenseCostReduction": int,
-        "modernizeInfrastructureWithCloudNativeTechnologies": int,
-        "reduceOperationalOverheadWithManagedServices": int,
-        "speedOfMigration": int,
+        "licenseCostReduction": NotRequired[int],
+        "modernizeInfrastructureWithCloudNativeTechnologies": NotRequired[int],
+        "reduceOperationalOverheadWithManagedServices": NotRequired[int],
+        "speedOfMigration": NotRequired[int],
     },
-    total=False,
 )
 
 CollectorTypeDef = TypedDict(
     "CollectorTypeDef",
     {
-        "collectorHealth": CollectorHealthType,
-        "collectorId": str,
-        "collectorVersion": str,
-        "hostName": str,
-        "ipAddress": str,
-        "lastActivityTimeStamp": str,
-        "registeredTimeStamp": str,
+        "collectorHealth": NotRequired[CollectorHealthType],
+        "collectorId": NotRequired[str],
+        "collectorVersion": NotRequired[str],
+        "hostName": NotRequired[str],
+        "ipAddress": NotRequired[str],
+        "lastActivityTimeStamp": NotRequired[str],
+        "registeredTimeStamp": NotRequired[str],
     },
-    total=False,
 )
 
 DataCollectionDetailsTypeDef = TypedDict(
     "DataCollectionDetailsTypeDef",
     {
-        "completionTime": datetime,
-        "failed": int,
-        "inProgress": int,
-        "servers": int,
-        "startTime": datetime,
-        "status": AssessmentStatusType,
-        "success": int,
+        "completionTime": NotRequired[datetime],
+        "failed": NotRequired[int],
+        "inProgress": NotRequired[int],
+        "servers": NotRequired[int],
+        "startTime": NotRequired[datetime],
+        "status": NotRequired[AssessmentStatusType],
+        "success": NotRequired[int],
     },
-    total=False,
 )
 
 DatabaseConfigDetailTypeDef = TypedDict(
     "DatabaseConfigDetailTypeDef",
     {
-        "secretName": str,
+        "secretName": NotRequired[str],
     },
-    total=False,
 )
 
 DatabaseMigrationPreferenceTypeDef = TypedDict(
     "DatabaseMigrationPreferenceTypeDef",
     {
-        "heterogeneous": "HeterogeneousTypeDef",
-        "homogeneous": "HomogeneousTypeDef",
-        "noPreference": "NoDatabaseMigrationPreferenceTypeDef",
+        "heterogeneous": NotRequired["HeterogeneousTypeDef"],
+        "homogeneous": NotRequired["HomogeneousTypeDef"],
+        "noPreference": NotRequired["NoDatabaseMigrationPreferenceTypeDef"],
     },
-    total=False,
 )
 
 DatabasePreferencesTypeDef = TypedDict(
     "DatabasePreferencesTypeDef",
     {
-        "databaseManagementPreference": DatabaseManagementPreferenceType,
-        "databaseMigrationPreference": "DatabaseMigrationPreferenceTypeDef",
+        "databaseManagementPreference": NotRequired[DatabaseManagementPreferenceType],
+        "databaseMigrationPreference": NotRequired["DatabaseMigrationPreferenceTypeDef"],
     },
-    total=False,
 )
 
 GetApplicationComponentDetailsRequestRequestTypeDef = TypedDict(
@@ -401,27 +390,14 @@ GetRecommendationReportDetailsResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetServerDetailsRequestRequestTypeDef = TypedDict(
-    "_RequiredGetServerDetailsRequestRequestTypeDef",
+GetServerDetailsRequestRequestTypeDef = TypedDict(
+    "GetServerDetailsRequestRequestTypeDef",
     {
         "serverId": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
 )
-_OptionalGetServerDetailsRequestRequestTypeDef = TypedDict(
-    "_OptionalGetServerDetailsRequestRequestTypeDef",
-    {
-        "maxResults": int,
-        "nextToken": str,
-    },
-    total=False,
-)
-
-
-class GetServerDetailsRequestRequestTypeDef(
-    _RequiredGetServerDetailsRequestRequestTypeDef, _OptionalGetServerDetailsRequestRequestTypeDef
-):
-    pass
-
 
 GetServerDetailsResponseTypeDef = TypedDict(
     "GetServerDetailsResponseTypeDef",
@@ -451,10 +427,9 @@ GetServerStrategiesResponseTypeDef = TypedDict(
 GroupTypeDef = TypedDict(
     "GroupTypeDef",
     {
-        "name": Literal["ExternalId"],
-        "value": str,
+        "name": NotRequired[Literal["ExternalId"]],
+        "value": NotRequired[str],
     },
-    total=False,
 )
 
 HeterogeneousTypeDef = TypedDict(
@@ -467,40 +442,37 @@ HeterogeneousTypeDef = TypedDict(
 HomogeneousTypeDef = TypedDict(
     "HomogeneousTypeDef",
     {
-        "targetDatabaseEngine": List[Literal["None specified"]],
+        "targetDatabaseEngine": NotRequired[List[Literal["None specified"]]],
     },
-    total=False,
 )
 
 ImportFileTaskInformationTypeDef = TypedDict(
     "ImportFileTaskInformationTypeDef",
     {
-        "completionTime": datetime,
-        "id": str,
-        "importName": str,
-        "inputS3Bucket": str,
-        "inputS3Key": str,
-        "numberOfRecordsFailed": int,
-        "numberOfRecordsSuccess": int,
-        "startTime": datetime,
-        "status": ImportFileTaskStatusType,
-        "statusReportS3Bucket": str,
-        "statusReportS3Key": str,
+        "completionTime": NotRequired[datetime],
+        "id": NotRequired[str],
+        "importName": NotRequired[str],
+        "inputS3Bucket": NotRequired[str],
+        "inputS3Key": NotRequired[str],
+        "numberOfRecordsFailed": NotRequired[int],
+        "numberOfRecordsSuccess": NotRequired[int],
+        "startTime": NotRequired[datetime],
+        "status": NotRequired[ImportFileTaskStatusType],
+        "statusReportS3Bucket": NotRequired[str],
+        "statusReportS3Key": NotRequired[str],
     },
-    total=False,
 )
 
 ListApplicationComponentsRequestRequestTypeDef = TypedDict(
     "ListApplicationComponentsRequestRequestTypeDef",
     {
-        "applicationComponentCriteria": ApplicationComponentCriteriaType,
-        "filterValue": str,
-        "groupIdFilter": Sequence["GroupTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-        "sort": SortOrderType,
+        "applicationComponentCriteria": NotRequired[ApplicationComponentCriteriaType],
+        "filterValue": NotRequired[str],
+        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
+        "sort": NotRequired[SortOrderType],
     },
-    total=False,
 )
 
 ListApplicationComponentsResponseTypeDef = TypedDict(
@@ -515,10 +487,9 @@ ListApplicationComponentsResponseTypeDef = TypedDict(
 ListCollectorsRequestRequestTypeDef = TypedDict(
     "ListCollectorsRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListCollectorsResponseTypeDef = TypedDict(
@@ -533,10 +504,9 @@ ListCollectorsResponseTypeDef = TypedDict(
 ListImportFileTaskRequestRequestTypeDef = TypedDict(
     "ListImportFileTaskRequestRequestTypeDef",
     {
-        "maxResults": int,
-        "nextToken": str,
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
     },
-    total=False,
 )
 
 ListImportFileTaskResponseTypeDef = TypedDict(
@@ -551,14 +521,13 @@ ListImportFileTaskResponseTypeDef = TypedDict(
 ListServersRequestRequestTypeDef = TypedDict(
     "ListServersRequestRequestTypeDef",
     {
-        "filterValue": str,
-        "groupIdFilter": Sequence["GroupTypeDef"],
-        "maxResults": int,
-        "nextToken": str,
-        "serverCriteria": ServerCriteriaType,
-        "sort": SortOrderType,
+        "filterValue": NotRequired[str],
+        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
+        "maxResults": NotRequired[int],
+        "nextToken": NotRequired[str],
+        "serverCriteria": NotRequired[ServerCriteriaType],
+        "sort": NotRequired[SortOrderType],
     },
-    total=False,
 )
 
 ListServersResponseTypeDef = TypedDict(
@@ -573,11 +542,10 @@ ListServersResponseTypeDef = TypedDict(
 ManagementPreferenceTypeDef = TypedDict(
     "ManagementPreferenceTypeDef",
     {
-        "awsManagedResources": "AwsManagedResourcesTypeDef",
-        "noPreference": "NoManagementPreferenceTypeDef",
-        "selfManageResources": "SelfManageResourcesTypeDef",
+        "awsManagedResources": NotRequired["AwsManagedResourcesTypeDef"],
+        "noPreference": NotRequired["NoManagementPreferenceTypeDef"],
+        "selfManageResources": NotRequired["SelfManageResourcesTypeDef"],
     },
-    total=False,
 )
 
 NetworkInfoTypeDef = TypedDict(
@@ -607,61 +575,55 @@ NoManagementPreferenceTypeDef = TypedDict(
 OSInfoTypeDef = TypedDict(
     "OSInfoTypeDef",
     {
-        "type": OSTypeType,
-        "version": str,
+        "type": NotRequired[OSTypeType],
+        "version": NotRequired[str],
     },
-    total=False,
 )
 
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef",
     {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "MaxItems": NotRequired[int],
+        "PageSize": NotRequired[int],
+        "StartingToken": NotRequired[str],
     },
-    total=False,
 )
 
 PrioritizeBusinessGoalsTypeDef = TypedDict(
     "PrioritizeBusinessGoalsTypeDef",
     {
-        "businessGoals": "BusinessGoalsTypeDef",
+        "businessGoals": NotRequired["BusinessGoalsTypeDef"],
     },
-    total=False,
 )
 
 PutPortfolioPreferencesRequestRequestTypeDef = TypedDict(
     "PutPortfolioPreferencesRequestRequestTypeDef",
     {
-        "applicationPreferences": "ApplicationPreferencesTypeDef",
-        "databasePreferences": "DatabasePreferencesTypeDef",
-        "prioritizeBusinessGoals": "PrioritizeBusinessGoalsTypeDef",
+        "applicationPreferences": NotRequired["ApplicationPreferencesTypeDef"],
+        "databasePreferences": NotRequired["DatabasePreferencesTypeDef"],
+        "prioritizeBusinessGoals": NotRequired["PrioritizeBusinessGoalsTypeDef"],
     },
-    total=False,
 )
 
 RecommendationReportDetailsTypeDef = TypedDict(
     "RecommendationReportDetailsTypeDef",
     {
-        "completionTime": datetime,
-        "s3Bucket": str,
-        "s3Keys": List[str],
-        "startTime": datetime,
-        "status": RecommendationReportStatusType,
-        "statusMessage": str,
+        "completionTime": NotRequired[datetime],
+        "s3Bucket": NotRequired[str],
+        "s3Keys": NotRequired[List[str]],
+        "startTime": NotRequired[datetime],
+        "status": NotRequired[RecommendationReportStatusType],
+        "statusMessage": NotRequired[str],
     },
-    total=False,
 )
 
 RecommendationSetTypeDef = TypedDict(
     "RecommendationSetTypeDef",
     {
-        "strategy": StrategyType,
-        "targetDestination": TargetDestinationType,
-        "transformationTool": "TransformationToolTypeDef",
+        "strategy": NotRequired[StrategyType],
+        "targetDestination": NotRequired[TargetDestinationType],
+        "transformationTool": NotRequired["TransformationToolTypeDef"],
     },
-    total=False,
 )
 
 ResponseMetadataTypeDef = TypedDict(
@@ -678,10 +640,9 @@ ResponseMetadataTypeDef = TypedDict(
 S3ObjectTypeDef = TypedDict(
     "S3ObjectTypeDef",
     {
-        "s3Bucket": str,
-        "s3key": str,
+        "s3Bucket": NotRequired[str],
+        "s3key": NotRequired[str],
     },
-    total=False,
 )
 
 SelfManageResourcesTypeDef = TypedDict(
@@ -694,70 +655,64 @@ SelfManageResourcesTypeDef = TypedDict(
 ServerDetailTypeDef = TypedDict(
     "ServerDetailTypeDef",
     {
-        "antipatternReportS3Object": "S3ObjectTypeDef",
-        "antipatternReportStatus": AntipatternReportStatusType,
-        "antipatternReportStatusMessage": str,
-        "applicationComponentStrategySummary": List["StrategySummaryTypeDef"],
-        "dataCollectionStatus": RunTimeAssessmentStatusType,
-        "id": str,
-        "lastAnalyzedTimestamp": datetime,
-        "listAntipatternSeveritySummary": List["AntipatternSeveritySummaryTypeDef"],
-        "name": str,
-        "recommendationSet": "RecommendationSetTypeDef",
-        "serverType": str,
-        "statusMessage": str,
-        "systemInfo": "SystemInfoTypeDef",
+        "antipatternReportS3Object": NotRequired["S3ObjectTypeDef"],
+        "antipatternReportStatus": NotRequired[AntipatternReportStatusType],
+        "antipatternReportStatusMessage": NotRequired[str],
+        "applicationComponentStrategySummary": NotRequired[List["StrategySummaryTypeDef"]],
+        "dataCollectionStatus": NotRequired[RunTimeAssessmentStatusType],
+        "id": NotRequired[str],
+        "lastAnalyzedTimestamp": NotRequired[datetime],
+        "listAntipatternSeveritySummary": NotRequired[List["AntipatternSeveritySummaryTypeDef"]],
+        "name": NotRequired[str],
+        "recommendationSet": NotRequired["RecommendationSetTypeDef"],
+        "serverType": NotRequired[str],
+        "statusMessage": NotRequired[str],
+        "systemInfo": NotRequired["SystemInfoTypeDef"],
     },
-    total=False,
 )
 
 ServerStrategyTypeDef = TypedDict(
     "ServerStrategyTypeDef",
     {
-        "isPreferred": bool,
-        "numberOfApplicationComponents": int,
-        "recommendation": "RecommendationSetTypeDef",
-        "status": StrategyRecommendationType,
+        "isPreferred": NotRequired[bool],
+        "numberOfApplicationComponents": NotRequired[int],
+        "recommendation": NotRequired["RecommendationSetTypeDef"],
+        "status": NotRequired[StrategyRecommendationType],
     },
-    total=False,
 )
 
 ServerSummaryTypeDef = TypedDict(
     "ServerSummaryTypeDef",
     {
-        "ServerOsType": ServerOsTypeType,
-        "count": int,
+        "ServerOsType": NotRequired[ServerOsTypeType],
+        "count": NotRequired[int],
     },
-    total=False,
 )
 
 SourceCodeRepositoryTypeDef = TypedDict(
     "SourceCodeRepositoryTypeDef",
     {
-        "branch": str,
-        "repository": str,
-        "versionControlType": str,
+        "branch": NotRequired[str],
+        "repository": NotRequired[str],
+        "versionControlType": NotRequired[str],
     },
-    total=False,
 )
 
 SourceCodeTypeDef = TypedDict(
     "SourceCodeTypeDef",
     {
-        "location": str,
-        "sourceVersion": str,
-        "versionControl": VersionControlType,
+        "location": NotRequired[str],
+        "sourceVersion": NotRequired[str],
+        "versionControl": NotRequired[VersionControlType],
     },
-    total=False,
 )
 
 StartAssessmentRequestRequestTypeDef = TypedDict(
     "StartAssessmentRequestRequestTypeDef",
     {
-        "s3bucketForAnalysisData": str,
-        "s3bucketForReportData": str,
+        "s3bucketForAnalysisData": NotRequired[str],
+        "s3bucketForReportData": NotRequired[str],
     },
-    total=False,
 )
 
 StartAssessmentResponseTypeDef = TypedDict(
@@ -768,31 +723,17 @@ StartAssessmentResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredStartImportFileTaskRequestRequestTypeDef = TypedDict(
-    "_RequiredStartImportFileTaskRequestRequestTypeDef",
+StartImportFileTaskRequestRequestTypeDef = TypedDict(
+    "StartImportFileTaskRequestRequestTypeDef",
     {
         "S3Bucket": str,
         "name": str,
         "s3key": str,
+        "dataSourceType": NotRequired[DataSourceTypeType],
+        "groupId": NotRequired[Sequence["GroupTypeDef"]],
+        "s3bucketForReportData": NotRequired[str],
     },
 )
-_OptionalStartImportFileTaskRequestRequestTypeDef = TypedDict(
-    "_OptionalStartImportFileTaskRequestRequestTypeDef",
-    {
-        "dataSourceType": DataSourceTypeType,
-        "groupId": Sequence["GroupTypeDef"],
-        "s3bucketForReportData": str,
-    },
-    total=False,
-)
-
-
-class StartImportFileTaskRequestRequestTypeDef(
-    _RequiredStartImportFileTaskRequestRequestTypeDef,
-    _OptionalStartImportFileTaskRequestRequestTypeDef,
-):
-    pass
-
 
 StartImportFileTaskResponseTypeDef = TypedDict(
     "StartImportFileTaskResponseTypeDef",
@@ -805,10 +746,9 @@ StartImportFileTaskResponseTypeDef = TypedDict(
 StartRecommendationReportGenerationRequestRequestTypeDef = TypedDict(
     "StartRecommendationReportGenerationRequestRequestTypeDef",
     {
-        "groupIdFilter": Sequence["GroupTypeDef"],
-        "outputFormat": OutputFormatType,
+        "groupIdFilter": NotRequired[Sequence["GroupTypeDef"]],
+        "outputFormat": NotRequired[OutputFormatType],
     },
-    total=False,
 )
 
 StartRecommendationReportGenerationResponseTypeDef = TypedDict(
@@ -829,86 +769,55 @@ StopAssessmentRequestRequestTypeDef = TypedDict(
 StrategyOptionTypeDef = TypedDict(
     "StrategyOptionTypeDef",
     {
-        "isPreferred": bool,
-        "strategy": StrategyType,
-        "targetDestination": TargetDestinationType,
-        "toolName": TransformationToolNameType,
+        "isPreferred": NotRequired[bool],
+        "strategy": NotRequired[StrategyType],
+        "targetDestination": NotRequired[TargetDestinationType],
+        "toolName": NotRequired[TransformationToolNameType],
     },
-    total=False,
 )
 
 StrategySummaryTypeDef = TypedDict(
     "StrategySummaryTypeDef",
     {
-        "count": int,
-        "strategy": StrategyType,
+        "count": NotRequired[int],
+        "strategy": NotRequired[StrategyType],
     },
-    total=False,
 )
 
 SystemInfoTypeDef = TypedDict(
     "SystemInfoTypeDef",
     {
-        "cpuArchitecture": str,
-        "fileSystemType": str,
-        "networkInfoList": List["NetworkInfoTypeDef"],
-        "osInfo": "OSInfoTypeDef",
+        "cpuArchitecture": NotRequired[str],
+        "fileSystemType": NotRequired[str],
+        "networkInfoList": NotRequired[List["NetworkInfoTypeDef"]],
+        "osInfo": NotRequired["OSInfoTypeDef"],
     },
-    total=False,
 )
 
 TransformationToolTypeDef = TypedDict(
     "TransformationToolTypeDef",
     {
-        "description": str,
-        "name": TransformationToolNameType,
-        "tranformationToolInstallationLink": str,
+        "description": NotRequired[str],
+        "name": NotRequired[TransformationToolNameType],
+        "tranformationToolInstallationLink": NotRequired[str],
     },
-    total=False,
 )
 
-_RequiredUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateApplicationComponentConfigRequestRequestTypeDef",
+UpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
+    "UpdateApplicationComponentConfigRequestRequestTypeDef",
     {
         "applicationComponentId": str,
+        "inclusionStatus": NotRequired[InclusionStatusType],
+        "secretsManagerKey": NotRequired[str],
+        "sourceCodeList": NotRequired[Sequence["SourceCodeTypeDef"]],
+        "strategyOption": NotRequired["StrategyOptionTypeDef"],
     },
 )
-_OptionalUpdateApplicationComponentConfigRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateApplicationComponentConfigRequestRequestTypeDef",
-    {
-        "inclusionStatus": InclusionStatusType,
-        "secretsManagerKey": str,
-        "sourceCodeList": Sequence["SourceCodeTypeDef"],
-        "strategyOption": "StrategyOptionTypeDef",
-    },
-    total=False,
-)
 
-
-class UpdateApplicationComponentConfigRequestRequestTypeDef(
-    _RequiredUpdateApplicationComponentConfigRequestRequestTypeDef,
-    _OptionalUpdateApplicationComponentConfigRequestRequestTypeDef,
-):
-    pass
-
-
-_RequiredUpdateServerConfigRequestRequestTypeDef = TypedDict(
-    "_RequiredUpdateServerConfigRequestRequestTypeDef",
+UpdateServerConfigRequestRequestTypeDef = TypedDict(
+    "UpdateServerConfigRequestRequestTypeDef",
     {
         "serverId": str,
+        "strategyOption": NotRequired["StrategyOptionTypeDef"],
     },
 )
-_OptionalUpdateServerConfigRequestRequestTypeDef = TypedDict(
-    "_OptionalUpdateServerConfigRequestRequestTypeDef",
-    {
-        "strategyOption": "StrategyOptionTypeDef",
-    },
-    total=False,
-)
-
-
-class UpdateServerConfigRequestRequestTypeDef(
-    _RequiredUpdateServerConfigRequestRequestTypeDef,
-    _OptionalUpdateServerConfigRequestRequestTypeDef,
-):
-    pass
